@@ -17,6 +17,7 @@ from telliot_core.contract.listener import Listener
 from telliot_core.directory import contract_directory
 from telliot_core.logs import init_logging
 from telliot_core.model.endpoints import RPCEndpoint
+from telliot_core.tellor.tellorflex.autopay import TellorFlexAutopayContract
 from telliot_core.tellor.tellorflex.oracle import TellorFlexOracleContract
 from telliot_core.tellor.tellorflex.token import TokenContract
 from telliot_core.tellor.tellorx.master import TellorxMasterContract
@@ -31,6 +32,11 @@ NETWORKS = {
     137: "polygon-mainnet",
     80001: "polygon-mumbai",
     122: "fuse-mainnet",
+    69: "optimism-kovan",
+    1666600000: "harmony-mainnet",
+    1666700000: "harmony-testnet",
+    421611: "arbitrum-rinkeby",
+    941: "pulsechain-testnet",
 }
 
 LOGLEVEL_MAP = {
@@ -53,6 +59,7 @@ class TellorxContractSet:
 @dataclass
 class TellorFlexContractSet:
     oracle: TellorFlexOracleContract
+    autopay: TellorFlexAutopayContract
     token: TokenContract
 
 
@@ -81,10 +88,10 @@ class TelliotCore:
             token = TokenContract(node=self.endpoint, account=account)
             token.connect()
 
-            self._tellorflex = TellorFlexContractSet(
-                oracle=oracle,
-                token=token,
-            )
+            autopay = TellorFlexAutopayContract(node=self.endpoint, account=account)
+            autopay.connect()
+
+            self._tellorflex = TellorFlexContractSet(oracle=oracle, token=token, autopay=autopay)
 
         return self._tellorflex
 
