@@ -59,6 +59,41 @@ default_chain_list = [
         network="testnet",
         currency=EVMCurrency(name="Matic", symbol="tMATIC", decimals=18),
     ),
+    Chain(
+        chain_id=69,
+        name="Optimism Kovan",
+        chain="Optimism",
+        network="testnet (public)",
+        currency=EVMCurrency(name="Ether", symbol="ETH", decimals=18),
+    ),
+    Chain(
+        chain_id=1666600000,
+        name="Harmony Mainnet",
+        chain="Harmony",
+        network="mainnet",
+        currency=EVMCurrency(name="Harmony ONE", symbol="ONE", decimals=18),
+    ),
+    Chain(
+        chain_id=1666700000,
+        name="Harmony Testnet",
+        chain="Harmony",
+        network="testnet",
+        currency=EVMCurrency(name="Harmony ONE", symbol="ONE", decimals=18),
+    ),
+    Chain(
+        chain_id=421611,
+        name="Arbitrum Rinkeby",
+        chain="Arbitrum",
+        network="testnet",
+        currency=EVMCurrency(name="Ether", symbol="ETH", decimals=18),
+    ),
+    Chain(
+        chain_id=941,
+        name="Pulsechain Testnet",
+        chain="Pulechain",
+        network="testnet",
+        currency=EVMCurrency(name="Pulsechain tPLS", symbol="tPLS", decimals=18),
+    ),
 ]
 
 
