@@ -8,6 +8,7 @@ from telliot_core.contract.listener import block_logger
 
 
 async def block_printer(msg) -> None:
+    """Print block info"""
     sub_id = msg["params"]["subscription"]
     block = msg["params"]["result"]
     print(f"handled block subscription: {sub_id}")
@@ -15,9 +16,10 @@ async def block_printer(msg) -> None:
 
 
 @pytest.mark.asyncio
-async def test_subscribe_new_blocks(caplog, rinkeby_cfg):
+async def test_subscribe_new_blocks(caplog, mumbai_test_cfg):
+    """Test the block listener"""
     caplog.set_level(logging.INFO)
-    async with TelliotCore(config=rinkeby_cfg) as core:
+    async with TelliotCore(config=mumbai_test_cfg) as core:
         # Subscribe to blocks
         await core.listener.subscribe_new_blocks(handler=block_logger)
         await asyncio.sleep(1)  # Note delay needed
